﻿namespace UltraGridSpecialSelection
{
    using System;
    using System.Data;
    using System.Windows.Forms;
    using Infragistics.Win.UltraWinGrid;

    public partial class Form1 : Form
    {
        private UltraGridCell activeCellCached = null;
        public Form1()
        {
            InitializeComponent();
            this.Load += Form1_Load;
            this.ultraGrid1.InitializeLayout += UltraGrid1_InitializeLayout;
            this.ultraGrid1.BeforeSelectChange += UltraGrid1_BeforeSelectChange;
            this.ultraGrid1.AfterSelectChange += UltraGrid1_AfterSelectChange;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //  Add some dummy data to the grid
            var data = this.GetData();
            this.ultraGrid1.SetDataBinding(data, data.TableName);
        }

        private void UltraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            //  Set up the grid so the user can select cells while dragging
            e.Layout.Override.CellClickAction = CellClickAction.CellSelect;
        }

        private void UltraGrid1_BeforeSelectChange(object sender, BeforeSelectChangeEventArgs e)
        {
            //  If the new selection is of cells get a reference to the first
            //  selected cell and assign it to the cached active cell field
            if(e.NewSelections.Cells.Count == 1)
            {
                this.activeCellCached = this.ultraGrid1.ActiveCell;
            }
        }

        private void UltraGrid1_AfterSelectChange(object sender, AfterSelectChangeEventArgs e)
        {
            //  If cashed active cell is not null set the grid active cell to
            //  refer to this cached cell value
            if(this.activeCellCached != null)
            {
                this.ultraGrid1.ActiveCell = this.activeCellCached;
            }
        }
        
        private DataTable GetData(int rows = 20, int cols = 5)
        {
            DataTable dt = new DataTable();

            for(int col = 0; col < cols; col++)
            {
                dt.Columns.Add(string.Format("Column #{0}", col + 1));
            }

            for(int row = 0; row < rows; row++)
            {
                DataRow addRow = dt.NewRow();
                foreach(DataColumn column in dt.Columns)
                {
                    addRow[column] = string.Format("{0}.{1}", row + 1, column.Ordinal + 1);
                }

                dt.Rows.Add(addRow);
            }

            return dt;
        }
    }
}
